@@ -56,8 +56,8 @@ use Perl6::Junction qw(any);
 use Time::HiRes qw/gettimeofday/;
 require Webservice::InterMine::Path;
 
-my @JSON_FORMATS = (qw/jsonobjects jsonrows jsondatatable/);
-my @SIMPLE_FORMATS = (qw/ tsv tab csv count xml/);
+my @JSON_FORMATS = (qw/jsonobjects jsonrows jsondatatable json/);
+my @SIMPLE_FORMATS = (qw/tsv tab csv count xml/);
 
 =head2 new( $url, [$user, $pass] )
 
@@ -727,6 +727,8 @@ sub get_request_format {
     my $row_format = shift;
     if ($row_format eq any(@SIMPLE_FORMATS, @JSON_FORMATS)) {
         return $row_format;
+    } elsif ($self->version >= 8) { # Not available earlier...
+        return "json";
     } else {
         return "jsonrows";
     }
